from pathlib import Path
from typing import ClassVar
from pydantic_settings import BaseSettings


class Settings(BaseSettings):
    API_V1_STR: str = "/api/v1"
    PROJECT_NAME: str = "Todo App API"
    PROJECT_DESCRIPTION: str = "A simple Todo app API built with FastAPI and SQLite"
    PROJECT_VERSION: str = "0.1.0"

    # Database settings
    DB_DIR: ClassVar[Path] = Path("/app") / "storage" / "db"
    DB_DIR.mkdir(parents=True, exist_ok=True)
    SQLALCHEMY_DATABASE_URL: str = f"sqlite:///{DB_DIR}/db.sqlite"

    model_config = {
        "case_sensitive": True,
        "env_file": ".env",
    }


settings = Settings()
